@@ -36,7 +36,7 @@ class KDFPRIVATE_EXPORT DiskEntry : public QObject
     public:
         explicit DiskEntry(QObject *parent=nullptr, const QString &name=QString());
         explicit DiskEntry(const QString & deviceName, QObject *parent=nullptr, const QString &name=QString());
-        ~DiskEntry();
+        ~DiskEntry() override;
         QString lastSysError() {return sysStringErrOut; }
         QString deviceName() const { return device; }
         // The real device (in case deviceName() is a symlink)
@@ -134,7 +134,6 @@ class KDFPRIVATE_EXPORT DiskEntry : public QObject
     private:
         void init(const QString &name);
         int sysCall(QString & command);
-        QString prettyPrint(int kBValue) const;
 
         KProcess     *sysProc;
         QString           sysStringErrOut;
