@@ -33,7 +33,7 @@ class KDFPRIVATE_EXPORT COptionDialog : public KPageDialog
 
     public:
         explicit COptionDialog( QWidget *parent=nullptr );
-        ~COptionDialog();
+        ~COptionDialog() override;
 
     protected Q_SLOTS:
         void slotOk();
@@ -45,8 +45,8 @@ class KDFPRIVATE_EXPORT COptionDialog : public KPageDialog
         void valueChanged();
 
     private:
-        KDFConfigWidget *mConf;
-        MntConfigWidget *mMnt;
+        KDFConfigWidget *mConf = nullptr;
+        MntConfigWidget *mMnt = nullptr;
         bool dataChanged;
 };
 
